@@ -35,3 +35,15 @@ class PayInvoiceError(UserError):
 
 class InvoicePaymentTermDateWarning(UserWarning):
     pass
+
+
+class InvoiceFutureWarning(UserWarning):
+    pass
+
+
+class InvoiceSimilarWarning(UserWarning):
+    pass
+
+
+class CancelInvoiceMoveWarning(UserWarning):
+    pass
