@@ -1,12 +1,9 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
-from trytond import backend
 from trytond.i18n import gettext
-from trytond.model import ModelView, ModelSQL, ValueMixin, fields
-from trytond.pool import Pool, PoolMeta
-from trytond.tools.multivalue import migrate_property
-
+from trytond.model import ModelSQL, ValueMixin, fields
 from trytond.modules.party.exceptions import EraseError
+from trytond.pool import Pool, PoolMeta
 
 customer_payment_term = fields.Many2One(
     'account.invoice.payment_term', "Customer Payment Term")
@@ -31,7 +28,7 @@ class ContactMechanism(metaclass=PoolMeta):
         return super(ContactMechanism, cls).usages(_fields=_fields)
 
 
-class Party(ModelSQL, ModelView):
+class Party(metaclass=PoolMeta):
     __name__ = 'party.party'
     customer_payment_term = fields.MultiValue(customer_payment_term)
     supplier_payment_term = fields.MultiValue(supplier_payment_term)
@@ -59,27 +56,10 @@ class PartyPaymentTerm(ModelSQL, ValueMixin):
     "Party Payment Term"
     __name__ = 'party.party.payment_term'
     party = fields.Many2One(
-        'party.party', "Party", ondelete='CASCADE', select=True)
+        'party.party', "Party", ondelete='CASCADE')
     customer_payment_term = customer_payment_term
     supplier_payment_term = supplier_payment_term
 
-    @classmethod
-    def __register__(cls, module_name):
-        exist = backend.TableHandler.table_exist(cls._table)
-
-        super(PartyPaymentTerm, cls).__register__(module_name)
-
-        if not exist:
-            cls._migrate_property([], [], [])
-
-    @classmethod
-    def _migrate_property(cls, field_names, value_names, fields):
-        field_names.extend(['customer_payment_term', 'supplier_payment_term'])
-        value_names.extend(['customer_payment_term', 'supplier_payment_term'])
-        migrate_property(
-            'party.party', field_names, cls, value_names,
-            parent='party', fields=fields)
-
 
 class Replace(metaclass=PoolMeta):
     __name__ = 'party.replace'
@@ -89,6 +69,7 @@ class Replace(metaclass=PoolMeta):
         return super().fields_to_replace() + [
             ('account.invoice', 'party'),
             ('account.invoice.line', 'party'),
+            ('account.invoice.alternative_payee', 'party'),
             ]
 
 
@@ -101,7 +82,10 @@ class Erase(metaclass=PoolMeta):
         super().check_erase_company(party, company)
 
         invoices = Invoice.search([
-                ('party', '=', party.id),
+                ['OR',
+                    ('party', '=', party.id),
+                    ('alternative_payees', '=', party.id),
+                    ],
                 ('company', '=', company.id),
                 ('state', 'not in', ['paid', 'cancelled']),
                 ])
