@@ -332,7 +332,7 @@ class TestPaymentTermView(ModelView):
         pool = Pool()
         Company = pool.get('company.company')
         company = Transaction().context.get('company')
-        if company:
+        if company is not None and company >= 0:
             return Company(company).currency.id
 
     @fields.depends('payment_term', 'date', 'amount', 'currency', 'result')
